@@ -87,6 +87,7 @@
 #define HAVE_SYS_UTSNAME_H 1
 #define HAVE_SYS_STAT_H 1
 /* #undef HAVE_SYS_STREAM_H */
+#define HAVE_SYS_SYSCALL_H 1
 /* #undef HAVE_SYS_TERMCAP_H */
 /* #undef HAVE_SYS_TIMEB_H */
 #define HAVE_SYS_TIMES_H 1
@@ -95,6 +96,7 @@
 #define HAVE_SYS_UN_H 1
 /* #undef HAVE_SYS_VADVISE_H */
 #define HAVE_SYS_STATVFS_H 1
+#define HAVE_UCONTEXT_H 1
 #define HAVE_TERM_H 1
 /* #undef HAVE_TERMBITS_H */
 #define HAVE_TERMIOS_H 1
@@ -119,6 +121,7 @@
 #define HAVE_LIBCRYPT 1
 /* #undef HAVE_LIBMTMALLOC */
 /* #undef HAVE_LIBWRAP */
+/* #undef HAVE_SYSTEMD */
 /* Does "struct timespec" have a "sec" and "nsec" field? */
 /* #undef HAVE_TIMESPEC_TS_SEC */
 
@@ -218,9 +221,11 @@
 #define HAVE_POSIX_FALLOCATE 1
 #define HAVE_LINUX_FALLOC_H 1
 /* #undef HAVE_FALLOCATE */
+/* #undef HAVE_FALLOC_PUNCH_HOLE_AND_KEEP_SIZE */
 #define HAVE_PREAD 1
 #define HAVE_PAUSE_INSTRUCTION 1
 /* #undef HAVE_FAKE_PAUSE_INSTRUCTION */
+/* #undef HAVE_HMT_PRIORITY_INSTRUCTION */
 /* #undef HAVE_RDTSCLL */
 /* #undef HAVE_READ_REAL_TIME */
 /* #undef HAVE_PTHREAD_ATTR_CREATE */
@@ -294,7 +299,6 @@
 /* #undef HAVE_THR_YIELD */
 #define HAVE_TIME 1
 #define HAVE_TIMES 1
-/* #undef HAVE_UCONTEXT */
 #define HAVE_VALLOC 1
 #define HAVE_VIDATTR 1
 #define HAVE_VIO_READ_BUFF 1
@@ -322,6 +326,8 @@
 /* #undef HAVE_TIMESPEC_TS_SEC */
 #define STRUCT_DIRENT_HAS_D_INO 1
 /* #undef STRUCT_DIRENT_HAS_D_NAMLEN */
+#define STRUCT_TIMESPEC_HAS_TV_SEC 1
+#define STRUCT_TIMESPEC_HAS_TV_NSEC 1
 #define SPRINTF_RETURNS_INT 1
 
 #define USE_MB 1
@@ -401,7 +407,7 @@
 
 #define HAVE_MBSTATE_T 1
 
-#define MAX_INDEXES 64
+#define MAX_INDEXES 64U
 
 #define QSORT_TYPE_IS_VOID 1
 #define RETQSORTTYPE void
@@ -409,6 +415,7 @@
 #define SIGNAL_RETURN_TYPE_IS_VOID 1
 #define RETSIGTYPE void
 #define VOID_SIGHANDLER 1
+#define HAVE_SIGHANDLER_T 1
 #define STRUCT_RLIMIT struct rlimit
 
 #ifdef __APPLE__
@@ -462,13 +469,13 @@
 
 #define HAVE_WEAK_SYMBOL 1
 #define HAVE_ABI_CXA_DEMANGLE 1
-
+#define HAVE_ATTRIBUTE_CLEANUP 1
 
 #define HAVE_POSIX_SIGNALS 1
 /* #undef HAVE_BSD_SIGNALS */
 /* #undef HAVE_SVR3_SIGNALS */
 /* #undef HAVE_V7_SIGNALS */
-
+/* #undef HAVE_ERR_remove_thread_state */
 
 /* #undef HAVE_SOLARIS_STYLE_GETHOST */
 
@@ -493,6 +500,7 @@
 
 #define SYSTEM_TYPE "Linux"
 #define MACHINE_TYPE "x86_64"
+#define DEFAULT_MACHINE "x86_64"
 /* #undef HAVE_DTRACE */
 
 #define SIGNAL_WITH_VIO_CLOSE 1
@@ -518,6 +526,10 @@
 /* #undef strtoll */
 /* #undef strtoull */
 /* #undef vsnprintf */
+#if (_MSC_VER > 1800)
+#define tzname _tzname
+#define P_tmpdir "C:\\TEMP"
+#endif
 #if (_MSC_VER > 1310)
 # define HAVE_SETENV
 #define setenv(a,b,c) _putenv_s(a,b)
@@ -526,7 +538,7 @@
 
 /* We don't want the min/max macros */
 #ifdef __WIN__
-#define NOMINMAX
+#define NOMINMAX 1
 #endif
 
 /*
@@ -629,19 +641,19 @@
 
 #define MYSQL_VERSION_MAJOR 10
 #define MYSQL_VERSION_MINOR 1
-#define MYSQL_VERSION_PATCH 6
+#define MYSQL_VERSION_PATCH 17
 #define MYSQL_VERSION_EXTRA ""
 
 #define PACKAGE "mysql"
 #define PACKAGE_BUGREPORT ""
 #define PACKAGE_NAME "MySQL Server"
-#define PACKAGE_STRING "MySQL Server 10.1.6"
+#define PACKAGE_STRING "MySQL Server 10.1.17"
 #define PACKAGE_TARNAME "mysql"
-#define PACKAGE_VERSION "10.1.6"
-#define VERSION "10.1.6"
+#define PACKAGE_VERSION "10.1.17"
+#define VERSION "10.1.17"
 #define PROTOCOL_VERSION 10
 
-#define MALLOC_LIBRARY "system jemalloc"
+#define MALLOC_LIBRARY "bundled jemalloc"
 
 /* time_t related defines */
 
